NLSL: stats.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
stats.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
double precision function | chi (p, nu)
double precision function | pchi (chi)
double precision function | residx ()
double precision function | corrl ()
double precision function | betai (a, b, x)
double precision function | betacf (a, b, x)
double precision function | alphat (t)
double precision function | alphaf (f)
double precision function | ts (al, nu)
double precision function | fs (al, nu1, nu2)
double precision function | gammq (a, x)
subroutine | gcf (gammcf, a, x, gln)
subroutine | gser (gamser, a, x, gln)
double precision function | gammln (xx)
subroutine | zbrac (func, x1, x2, succes)
double precision function | zbrent (func, x1, x2, tol)
subroutine | pausex (mesg)

## Function/Subroutine Documentation

double precision function alphaf | ( | double precision | f | ) |

Definition at line 287 of file stats.f90.

double precision function alphat | ( | double precision | t | ) |

Definition at line 272 of file stats.f90.

double precision function betacf | ( | double precision | a,
|  | double precision | b,
|  | double precision | x
| ) |  |

Definition at line 213 of file stats.f90.

double precision function betai | ( | double precision | a,
|  | double precision | b,
|  | double precision | x
| ) |  |

Definition at line 172 of file stats.f90.

Here is the call graph for this function:

double precision function chi | ( | double precision | p,
|  | integer | nu
| ) |  |

Definition at line 37 of file stats.f90.

Here is the call graph for this function:

double precision function corrl | ( |  | ) |

Definition at line 120 of file stats.f90.

double precision function fs | ( | double precision | al,
|  | integer | nu1,
|  | integer | nu2
| ) |  |

Definition at line 326 of file stats.f90.

Here is the call graph for this function:

double precision function gammln | ( | double precision | xx | ) |

Definition at line 460 of file stats.f90.

double precision function gammq | ( | double precision | a,
|  | double precision | x
| ) |  |

Definition at line 359 of file stats.f90.

Here is the call graph for this function:

subroutine gcf | ( | double precision | gammcf,
|  | double precision | a,
|  | double precision | x,
|  | double precision | gln
| ) |  |

Definition at line 384 of file stats.f90.

Here is the call graph for this function:

Here is the caller graph for this function:

subroutine gser | ( | double precision | gamser,
|  | double precision | a,
|  | double precision | x,
|  | double precision | gln
| ) |  |

Definition at line 423 of file stats.f90.

Here is the call graph for this function:

Here is the caller graph for this function:

subroutine pausex | ( | character*(*) | mesg | ) |

Definition at line 587 of file stats.f90.

Here is the caller graph for this function:

double precision function pchi | ( | double precision | chi | ) |

Definition at line 68 of file stats.f90.

double precision function residx | ( |  | ) |

Definition at line 88 of file stats.f90.

double precision function ts | ( | double precision | al,
|  | integer | nu
| ) |  |

Definition at line 301 of file stats.f90.

Here is the call graph for this function:

subroutine zbrac | ( | external | func,
|  | double precision | x1,
|  | double precision | x2,
|  | logical | succes
| ) |  |

Definition at line 485 of file stats.f90.

Here is the call graph for this function:

Here is the caller graph for this function:

double precision function zbrent | ( | external | func,
|  | double precision | x1,
|  | double precision | x2,
|  | double precision | tol
| ) |  |

Definition at line 512 of file stats.f90.

Here is the call graph for this function: